3.1 (unreleased)
================

New Features
------------

astropy.config
^^^^^^^^^^^^^^

astropy.convolution
^^^^^^^^^^^^^^^^^^^

- Example entry [#100]

Performance Improvements
------------------------

- An entry not in a specific subpackage. [#102]

astropy.visualization
^^^^^^^^^^^^^^^^^^^^^

- An entry in a subpackage. [#103]

3.0.1 (2018-03-12)
==================

Bug Fixes
---------

astropy.io.ascii
^^^^^^^^^^^^^^^^

- A bug fix. [#104]

- An entry that is over
  multiple lines. [#105]

- An entry with multiple issues. [#106, #107]

- An entry with multiple issues over multiple lines. [#108,
  #109]

0.1 (2012-06-19)
================

- Initial release, with no issue.
